@@ -3,15 +3,14 @@ use byteorder::LittleEndian;
 use crate::decode::{Decode, DecodeError};
 use crate::encode::Encode;
 use crate::io::{Buf, BufMut};
-use crate::mysql::protocol::Type;
-use crate::mysql::types::MySqlTypeMetadata;
+use crate::mysql::protocol::TypeId;
+use crate::mysql::types::MySqlTypeInfo;
 use crate::mysql::MySql;
 use crate::types::HasSqlType;
 
 impl HasSqlType<i8> for MySql {
-    #[inline]
-    fn metadata() -> MySqlTypeMetadata {
-        MySqlTypeMetadata::new(Type::TINY)
+    fn type_info() -> MySqlTypeInfo {
+        MySqlTypeInfo::new(TypeId::TINY_INT)
     }
 }
 
@@ -28,9 +27,8 @@ impl Decode<MySql> for i8 {
 }
 
 impl HasSqlType<i16> for MySql {
-    #[inline]
-    fn metadata() -> MySqlTypeMetadata {
-        MySqlTypeMetadata::new(Type::SHORT)
+    fn type_info() -> MySqlTypeInfo {
+        MySqlTypeInfo::new(TypeId::SMALL_INT)
     }
 }
 
@@ -47,9 +45,8 @@ impl Decode<MySql> for i16 {
 }
 
 impl HasSqlType<i32> for MySql {
-    #[inline]
-    fn metadata() -> MySqlTypeMetadata {
-        MySqlTypeMetadata::new(Type::LONG)
+    fn type_info() -> MySqlTypeInfo {
+        MySqlTypeInfo::new(TypeId::INT)
     }
 }
 
@@ -66,9 +63,8 @@ impl Decode<MySql> for i32 {
 }
 
 impl HasSqlType<i64> for MySql {
-    #[inline]
-    fn metadata() -> MySqlTypeMetadata {
-        MySqlTypeMetadata::new(Type::LONGLONG)
+    fn type_info() -> MySqlTypeInfo {
+        MySqlTypeInfo::new(TypeId::BIG_INT)
     }
 }
 
